;+
; Name: check_func_electron
; 
; Purpose: Check whether electron spectrum can be calculated for a function
; 
; Input Arguments:
;  func - Name of function to check, e.g. 'thick2_vnorm'
; 
; Output Keywords:
;  vnorm - 1 means func is normalized at a ref energy (not to integral of electron flux)
;  single_pow - 1 means func only has one power-law function
;  athin - 1 means func is one of the thin target functions
;  rc - 1 means func is a return current function
;  
; Output: Functions returns 0 or 1 meaning electron spectrum can not or can be calculated fot func.
;  
; Written: 8-Jul-2014, Kim Tolbert
; Modifications:
; 24-Jul-2015, Kim.  Added thick_warm to thick_func list
;-

function check_func_electron, func, vnorm=vnorm, single_pow=single_pow, athin=athin, rc=rc;, thinsm=thinsm

; Thick target functions we can calculate electron spectrum for
thick_func = ['thick', 'thick_warm', 'thick2', 'thick2_vnorm', 'photon_thick', 'thick_nui', 'thick2_rc']

; Thin target functions we can calculate electron spectrum for
thin_func = ['thin', 'thin2', 'photon_thin'] ;, 'thin2sm']

thick_thin_func = [thick_func, thin_func]
  
retval = is_member(func, thick_thin_func)

if retval ne 0 then begin
  vnorm_func = ['thick2_vnorm', 'thick2_rc']
  vnorm = is_member(func, vnorm_func)
  
  single_pl_func = ['thick_nui', 'thick2_rc']
  single_pow = is_member(func, single_pl_func)
  
  athin = is_member(func, thin_func)
  
  thinsm = func eq 'thin2sm'
  
  rc = func eq 'thick2_rc'
endif

return, retval
end