;+
; NAME:
;	f_drm_mod2_defaults
;
; PURPOSE: Function to return default values for
;   parameters, minimum and maximum range, and free parameter mask when
;   fitting with drm_mod2 function.  drm_mod2 is a pseudo function - the function
;   value is always 0., but the params are used to create a new RHESSI DRM.
;
; CALLING SEQUENCE: defaults = f_drm_mod_defaults()
;
; INPUTS:
;	None
; OUTPUTS:
;	Structure containing default values
;
; MODIFICATION HISTORY:
; Kim Tolbert, 27-Jun-2006 (copied from f_drm_mod_defaults and renamed)
;	ras, 1-may-2008 added blanket_coeff to replace center_thick ratio
;	15-Jul-2009, Kim. Change free default for blanket coeff (third param) to fixed.
;	20-Aug-2013, Kim. Added center_thickness_ratio parameter, and 3 place holders, and called it f_drm_mod2_defaults
;
;-
;------------------------------------------------------------------------------

FUNCTION f_drm_mod2_defaults

defaults = { $
  fit_comp_params:           [1.,  0.,  1.,  1., 0., 0., 0.], $  ; fwhm_frac, gain_offset, blanket_coeff, center_thickness, dummy, dummy, dummy
  fit_comp_minima:           [.5,  -1, .05,  0., 0., 0., 0.], $
  fit_comp_maxima:           [1.5, 1., 1.5, 10., 0., 0., 0.], $
  fit_comp_free_mask:        [1b,  1b,  0b,  0b, 0b, 0b, 0b] $

}

RETURN, defaults

END