;+
; Name: FERMI_TIM2MET
;
; Purpose: Convert time in any anytim format (such as seconds since 1-Jan-1979, or ASCII date) 
;   to Fermi Mission Elapsed time ((seconds since 1-Jan-2001 with no leap sec)
; 
; Calling sequence:  met = fermi_tim2met(time)
; 
; Argument:
;   time - time in any anytim format (look in header of anytim.pro for accepted formats)
;   
; Output - double precision time in Fermi mission elapsed time (seconds since 1-jan-2001 with no leap sec)
; 
; Example:
;   print,fermi_tim2met('12-jun-2010 00:00')
;     2.9799360e+008
;     
; Written, Kim Tolbert 24-May-2010
; Modifications:
; 07-Nov-2011. Kim.  Modified header doc.
; 
;-

function fermi_tim2met, time

ref_utc = anytim('1-jan-2001 00:00:00.000')

nleap = fermi_nleap_sec(time)

met = anytim(time) - ref_utc - nleap

return, met
end