;+
; Name: gbm_check_rsp
;
; Purpose: Check the fermi gbm rsp files for duplicate files for the same flare.  I'm not really sure
;   how this happened, but we had two sets of files for the same flares, i.e. same date_hhmm (which is
;   flare id) with different fractions of day. This routine will find them, delete all of the files for
;   that flare and remake them.  If a duplicate is found that doesn't correspond to a fermi flare, then
;   the program uses the time interval found in the header DATE-OBS, DATE-END fields to remake the files.
;   
;   Must be run on hesperia by softw account.
;   
;   This should be run by me every once in a while to clean up the rsp files.  Also run gbm_check_rsp_b0 to
;   remake any b0 files that weren't extended to 199 bins properly.
;   
; Calling sequence: gbm_check_rsp, out=out
;
; Output Keywords:
;   out - string array of all of the flares that were redone
; 
; Written: Kim Tolbert 4-Sep-2013
; 
;-

pro gbm_check_rsp, out=out

cat=gbm_read_cat()

f=file_search('/data/fermi/gbm/rsp','*.rsp*')

qb0 = where (strpos(f,'_b0_') ne -1, nb0)   ; use b0 files, but could have used any det
fb0 = f[qb0]

ids = stregex(file_basename(fb0),'[0-9]{6}_[0-9]{4}',/extract)

out = ''

for i=0,nb0-1 do begin  
  z = where(ids[i] eq ids, nid)  
  if nid gt 1 then dbl_ids = append_arr(dbl_ids, ids[i])
endfor

if ~exist(dbl_ids) then goto, done

dbl_ids = get_uniq(dbl_ids)
for i=0,n_elements(dbl_ids)-1 do begin
    id = dbl_ids[i]
    ff = file_search('/data/fermi/gbm/rsp','*'+id+'*.rsp*')
    dir = file_dirname(ff[0])
    text = 'Deleting all detector rsp files and remaking for flare ' + id
    print,text
    out = [out,text]
    
    if is_member(id, cat.id) then begin
      file_delete,ff, /verbose
      gbm_make_rsp, flare=id, outdir=dir, /cleanup 
    endif else begin
      a = mrdfits(ff[0], 0 , hdr)
      stime = fxpar(hdr, 'DATE-OBS')
      etime = fxpar(hdr, 'DATE-END')
      file_delete,ff, /verbose, /allow_nonexistent
      gbm_make_rsp, time_range=[stime,etime], outdir=dir, /cleanup
    endelse
    
endfor

done:
end

    