;+
; Name: gbm_find_rsp
; 
; Purpose - Retrieve GBM response files from hesperia archive.  The archive contains .rsp or .rsp2 files for all
;  time intervals that were identified as flares in an examination of the GBM data. There may also be some
;  response files that were created manually upon request.
; 
; Input keywords:
;   date - either a single time (assumes entire day), or a time range, in anytim
;          format (if seconds then sec since 1979/1/1)
;   det - string array of detectors to get files for.  If not set, get any det.  Choices are 
;         ['b0', 'b1', 'n0', 'n1', 'n2', 'n3', 'n4', 'n5', 'n6', 'n7', 'n8', 'n9', 'na', 'nb']
;   copy - if set, copy files to local computer, default is 1
;   dir - dir to copy to, default is current dir
;
; Output keywords:
;   count - number of files found/copied
;   file - name of files copied (if copy was set to 0, then contains names of URLs)
;   
; Examples:
;   Copy all response files for 12-jun-2010 to current directory
;     gbm_find_rsp, date='12-jun-2010'
;   Copy response files for 12-jun-2010 00:00 to 01:00  for NaI detector 5
;     gbm_find_rsp, date='12-jun-2010 ' + ['00:00', '01:00'], det='n5'
;
; 04-Nov-2011, Kim Tolbert
; Modifications:
;
;-

pro gbm_find_rsp, date=date, det=det, copy=copy, dir=dir, count=count, file=file, err=err

checkvar, copy, 1
checkvar, dir, curdir()

time_range = n_elements(date) eq 1 ? anytim(date, /date_only) + [0,86400.d0] : anytim(date)

spex_find_data, 'fermi_gbm_rsp', time_range, pattern=pattern, det=det, url=url, copy=copy, dir=dir, count=count, file=file, err=err

if ~copy then file = url

return
end