;+
; PROJECT:
;	FERMI
; NAME:
;	GBM_GET_FILETYPE
;
; PURPOSE:
;
;
; CATEGORY:
;	QUICKLOOK AND CATALOG GENERATION FOR FERMI GBM
;
; CALLING SEQUENCE:
;	these_files = gbm_get_filetype( daily_files, gbm_type, count)
;	Returns the file descriptors to the files of type GBM_TYPE in daily_files
; CALLS:
;	none
;
; INPUTS:
;       Daily_files - array of file names(fully qualified) or directory with files
;		GBM_TYPE - file name type for GBM: CSPEC, CTIME, POSHIST, SPECHIST,
;			CSPEC is the default
;
; OPTIONAL INPUTS:
;	none
;
; OUTPUTS:
;       Count
;
; OPTIONAL OUTPUTS:
;	none
;
; KEYWORDS:
;	EXTENSION - only get files with this extension, string, e.g. '.pha'
; COMMON BLOCKS:
;	none
;
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	Limited to the files for one day
;
; PROCEDURE:
;	none
;
; MODIFICATION HISTORY:
;	17-may-2010, ras, added extension
;	18-MAR-2010, richard.schwartz@nasa.gov
;
;-



function gbm_get_filetype, daily_files, gbm_type, count, nexpected=nexpected, extension=extension

default, extension, ''
default, gbm_type, 'cspec_n'
count = 0
nexpected = 0
nb = ['n','b']
types = ['cspec_'+nb,'ctime_'+nb,'spechist_'+nb,'poshist']
numbers = [12,2,12,2,12,2,1]
sn = where( strlowcase(gbm_type) eq types, gcount)
if gcount eq 1 then nexpected = numbers[sn[0]] else begin
	message,/info,'Invalid gbm file type.  Choose from '+arr2str(types+' ')
	return,''
	endelse


if is_dir(daily_files[0]) or ~file_exist(daily_files[0]) then begin
	default,daily_files,'C:\ssw\soft\gbm\2010-01-19'
	;path='C:\ssw\soft\gbm\2010-01-20'
	
	files = concat_dir(daily_files, '*'+gbm_type+'*'+extension)
	ff=file_search(files, count=fcount)
	if fcount lt nexpected then message,'Missing files for ' + files, /cont

	;print, path, ff[0]
endif else begin
	ff = daily_files
	sel_cspec = where( stregex(ff,gbm_type,/fold,/boolean), fcount)
	ff = fcount eq nexpected ? ff[sel_cspec] : ''

	if ~(total(file_exist(ff)) eq nexpected) or (fcount eq 0) then begin
		message,/info, 'Invalid file or path input in first argument, must provide all file names for day or daily directory name'
		return,''
		endif
endelse

count = ff[0] eq '' ? 0 : n_elements(ff)
return, ff
end
