;+
; Name: get_abun_table
;
; Purpose:  Retrieve information about abundance table in use
;
; Method:  If model is mewe, then abundance table is always mewe_solar, and we
;   call xr_rd_abundance to get array of abundances.  If model is chianti, then
;   we look at what has been stored in ab_type_sav and abundance variables
;   in chianti_kev_abundance common.
;
; Keywords:
;   model - scalar or array containing 'mewe' or 'chianti'
;   type - If set, return type of abundance (e.g. 'sun_coronal')
;   abun - If set, return array of abundances)
;
; Written: 27-Apr-2006, Kim Tolbert
;
;-


function get_abun_table, model=model, type=type, abun=abun

common chianti_kev_abundance, abundance, ab_file_sav, rel_abun_com, ab_type_sav, ab_sav

chianti = total(strmatch(model, '*chian*', /fold_case)) gt 0

if chianti then begin
	if keyword_set(type) then return, exist(ab_type_sav) ? ab_type_sav : ''

	return, exist(abundance) ? abundance : -1

endif else begin

	if keyword_set(type) then return, 'mewe_solar'
	return, xr_rd_abundance('mewe_solar')
endelse

end
