;+
; Description:
;    This procedure writes a new, better GRS matrix in a save file to be used in OSPEX. The new
;    output file, gerry_grs_drmnew.sav, is better than the one Gerry provided called 
;    DRM_MASS_BRD.TXT (used with en_wid.txt) for the reason below.
;    This procedure reads in the Gerry Share supplied MonteCarlo implementation of
;    the 476 channel detector response matrix in units of Counts / (ph/cm2) and shifts
;    the response to be at photon energy bin center.
;    Original info had photon energy centers and widths, but in order to make contiguous 
;    bins, centers are shifted.  The significant shifts for the energies at input bins 493 and 494,
;    are featureless, so can just interpolate the intensities across energies.
;    Output from this will be used in spex_grs_resp routine in OSPEX.
;
; Input Keywords:
;    save - if set write gerry_grs_drmnew.sav, IDL save file, in the current directory
;    drm_readfromfile - drm already read from G. Share supplied file (if not supplied, reads from G. Share file)
;    gfile_dir - path to G. Share file's input files
;    fits_dir  - path to FITS data file needed to get GRS spectrum file (to get count energy bins)
;
;    
;  Output Keywords:
;    drmnew  - modified Share DRM in original units
;
; :Author: raschwar, 27-mar-2019
;-
pro grs_mod_share_mc_drm, save = save, drm_readfromfile = drm_readfromfile, drmnew = drmnew, $
  gfile_dir = gfile_dir, fits_dir = fits_dir
  ; mod of share monte-carlo drm for response center shifts
  ;significant shifts for the energies at input 493 and 494,
  ; featureless, just interpolate the intensities across energies
  default, gfile_dir, 'C:\Users\raschwar\Downloads\'
  default, fits_dir, 'Z:\smm\grs\1980\'
  
  if exist( drm_readfromfile ) then drm = drm_readfromfile else begin
    drm_file = loc_file( path = [curdir(),gfile_dir],'drm_mass_brd.txt')
    if file_exist( drm_file ) then begin
      openr,1,drm_file
      drm = fltarr(476,500)
      readf,1,drm
      close,1
    endif
  endelse
  if ~exist( drm ) then message,"GShare MC drm, file nor data, not supplied"
  o=ospex(/no_gui, spex_specfile= concat_dir( fits_dir, 'smm_grs_19800328_0907_0956_DB.fits'))
  d=o->getdata()
  eout = o->getaxis(/ct_energy,/edges_2)
  spex_grs_resp, edges_out= eout, edges_in=ein, area=area, drm=grsmatrix
  efile = loc_file(path=[curdir(),gfile_dir], 'en_wid.txt')
  eold = float( rd_tfile(efile,2) ) * 1.e3
  emin = avg(ein,0)
  eminold= reform( eold[0,*])
  dbox = drm[*,492:495]
  drmnew = drm
  for j = 493, 494 do $
    for i=0,475 do drmnew[i,j] = interpol(reform( dbox[i,*]), eminold[492:495], emin[j])
  if keyword_set( save ) then save, file = 'gerry_grs_drmnew.sav', drmnew, eout, ein
end