;+
; Name: read_grs_4_ospex
;
; Purpose: Read grs flare FITS files into ospex.  Called by spex_smm_grs_specfile::read_data
;
; Written: Kim Tolbert 19-Mar-2019, Based on read_hxrbs_4_ospex
; Modifications:
;  19-Apr-2019, Kim.  Added files keyword to call to spex_grs_resp, and no longer passing in
;    edges_out to spex_grs_resp (now it's just returned)
;  22-Apr-2019, Kim. Added ercounts to args in call to rd_grs_fits, and use them as error in
;    counts (now that some files have bk-subtracted data, error isn't simple sqrt(counts)).
;  12-Jun-2019, Kim. Added HEM option to read GRS HEM data instead of main PHA data
;
;-

pro read_grs_4_ospex, FILES=files, hem=hem, data_str=data_str, ERR_CODE=err_code,$
  ERR_MSG=err_msg, _REF_EXTRA=_ref_extra, verbose=verbose

  checkvar, hem, 0

  data_str = -1
  err_code = 0
  err_msg = ''

  rd_grs_fits, files, hem=hem, ut_mid, counts, ercounts, livetime, ct_edges, deltat, error=err_code
  if err_code then return

  nt = n_elements(ut_mid)

  ut_edges = transpose([[ut_mid - deltat/2.],[ut_mid+ deltat/2.]])

  if hem then begin
    nen = n_elements(ct_edges[0,*])
    drm = fltarr(nen) + 1.
    edges_in = ct_edges
    area = 1. ;cm2  
  endif else begin
    spex_grs_resp, edges_out=edges_out, edges_in=edges_in, area=area, drm=drm, files=files, error=err_code


    if err_code ne 0 then begin
      message, /cont, 'Error reading GRS response matrix file. Not setting drm.''
      return
    endif

    if exist(edges_out) then begin
      rat = f_div(ct_edges, edges_out)
      if n_elements(ct_edges) ne n_elements(edges_out) or max(abs(1.0-rat)) gt .001 then begin
        message, /cont, 'Error - count edges from drm are not the same as from data.'
        print, "Using data file's count edges"
      endif
    endif
  endelse

  title = hem ? 'SMM GRS HEM' : 'SMM GRS'
  detused = hem ? 'GRS HEM' : 'GRS' 
  data_str = { $
    start_time: anytim(ut_edges[0,0], /vms), $
    end_time: anytim(ut_edges[1,nt-1], /vms), $
    rcounts: counts, $
    ercounts: ercounts, $
    ut_edges: ut_edges, $
    units: 'counts', $
    area: area, $
    ltime: livetime, $
    ct_edges: ct_edges, $
    title: title, $
    respinfo: {edges_in: edges_in, drm: drm}, $
    detused: detused, $
    atten_states: -1 }

end