;+
; Name: compute_grs_times2use
; 
; Purpose: Read the text file that shows what times to use for GRS files to ensure good background
;  subtraction, and write a save file with the time intervals for FD, DB, and DA files to use.
;  
; Wrtten: Kim Tolbert 8-Apr-2019
; 
;-

pro compute_grs_times2use

a=rd_tfile('USE_file_times2_edit.txt', /auto, delim=',')
qfd = where(strpos(a[0,*], 'FD') eq 6)
qdb = where(strpos(a[0,*], 'DB') eq 6)
qda = where(strpos(a[0,*], 'DA') eq 6)

sfd = a[*,qfd]
sdb = a[*,qdb]
sda = a[*,qda]

qfd = where(trim(sfd[6,*]) eq '1', nfd)
g = sfd[*,qfd]

t = reform(g[1,*])
dmb = reform(float(g[4,*])) ; d minus b in min
amd = reform(float(g[5,*])) ; a minus d in min
sd = reform(float(g[7,*]))  ; shift d in min
sb = reform(float(g[8,*]))  ; shift b in min
sa = reform(float(g[9,*]))  ; shift a in min

tz = [0.d, 0.d]
out = replicate({usename: '', fd_file_time: tz, db_file_time: tz, da_file_time: tz, fd_use_time: tz, db_use_time: tz, da_use_time: tz}, nfd)

for i=0,nfd-1 do begin
  usename = strmid(g[0,i], 0, 6)
  qb = where(strpos(sdb[0,*], usename) ne -1, nb)
  qa = where(strpos(sda[0,*], usename) ne -1, na)
  td = anytim([g[1,i], g[2,i]])
  newtd = [td[0] + 60.*sd[i], td[1]]
  min_dur = td[1] - td[0]
  if nb gt 0 and sb[i] ge 0 then begin
    tb = anytim([sdb[1,qb], sdb[2,qb]])
    newtb = [tb[0] + 60.*sb[i], tb[1]]
    min_dur = min_dur < (newtb[1] - newtb[0])
  endif else begin
    tb = tz
    newtb = tb
  endelse
  if na gt 0 and sa[i] ge 0 then begin
    ta = anytim([sda[1,qa], sda[2,qa]])
    newta = [ta[0] + 60.*sa[i], ta[1]]
    min_dur = min_dur < (newta[1] - newta[0])
  endif else begin
    ta = tz
    newta = ta
  endelse
  out[i].usename = usename
  out[i].fd_file_time = td
  out[i].db_file_time = tb
  out[i].da_file_time = ta
  out[i].fd_use_time = [newtd[0], newtd[0] + min_dur]
  out[i].db_use_time = newtb[0] gt 0. ? [newtb[0], newtb[0] + min_dur] : tz
  out[i].da_use_time = newta[0] gt 0. ? [newta[0], newta[0] + min_dur] : tz
endfor

out_dba = out
readme = ['SMM/GRS times to use for background subtraction. Kim Tolbert 22-Apr-2019', $
          'This save file contains the original file time intervals for the Flare Data, Day Before, and', $
          ' Day After (FD, DB, and DA) files in FD_FILE_TIME, DB_FILE_TIME, and DA_FILE_TIME, and ', $
          ' the time intervals to use for each (so that there are the same number of bins, and the bins', $
          ' cover the same orbital location) in FD_USE_TIME, DB_USE_TIME, AND DA_USE_TIME.', $
          ' All times are in seconds since 1979/1/1.']
save, file='grs_dba_times.sav', out_dba, readme

;utplot,g[1,*], float(g[4,*]), psym=2,yra=[80000,86500.]/60., /xst
;linecolors & outplot,g[1,*], float(g[4,*]) + sd - sb, psym=2,col=2
;
;utobj = obj_new('utplot', t, [[dmb],[amd]])
;utobj->plotman, psym=2, yrange=[1300,1500]

dmbnew = dmb + sd - sb
qb_bad = where(sb lt 0., nb_bad)  ; take care of -9999 values by setting dmbnew = 0. for those points
if nb_bad gt 0 then dmbnew[qb_bad] = 0.
amdnew = amd + sa - sd
qa_bad = where(sa lt 0., na_bad)  ; take care of -9999 values by setting smbnew = 0. for those points
if na_bad gt 0 then amdnew[qa_bad] = 0.
utobj = obj_new('utplot', t, [[amdnew],[dmbnew]])
utobj->plotman, psym=2, yrange=[1300,1500], ytitle='Minutes', $
  title='Difference between file start times', dim1_id=['After - Flare', 'Flare - Before']
end