;+
; Name: grs_read_use_file
;
; Purpose: Read SMM / GRS data from UNH-provided .USE files and return structure containing all data
;
; Calling sequence: struct = grs_read_use_file(usefile)
; 
; Input arguments: 
;  usefile - name of .USE file to read
;  
; Written: Kim Tolbert, 18-Mar-2019
; Modifications:
;-

function grs_read_use_file, file

  counts = grs_lightcurve( file=file, ut, ltime, edges,/pha_data,$
    start_time=start_time, end_time=end_time  )
  area = 317.55 ;cm2 for each detector
  nbin =n_elements(ut(0,*))
  ltime =  temporary( rebin(reform(ltime,1,nbin),476,nbin))
  nchan = 476
  edges = edges(*,0:nchan-1) * 1e3
  edge_products, edges, width=ww
  title = 'SMM GRS PHA '+atime(/yoh, ut(0),/date)
  wchan = indgen(200)+10

  ; convert to rate
  rate = f_div(counts, ltime)
  erate = f_div(sqrt(counts), ltime)

  ;convert to fluxes, counts/s/cm2/keV
  count_2_flux =  ltime * area * rebin(ww(*),nchan,nbin)
  eflux = f_div(sqrt(counts), count_2_flux) ;sqrt counts/ factors
  flux  = f_div(counts, count_2_flux)       ; counts / factors

  ; Now get structure with everything in file
  all_data = grs_extract(file)
  return, {flux:flux, eflux:eflux, rate: rate, erate: erate, $
    ut:ut, ltime:ltime, edges:edges, area:area, wchan:wchan, $
    all_data: all_data}
end