;+
; Name: spex_convert_2vth_to_twovth
; 
; Purpose: Convert an object set up to use the 2vth component to one using the two vth components.  2vth
;   has em,temp,em,temp,abun so move the first em,temp to one of the new vth, and second em,temp to second
;   new vth, and copy the single abun value to the 3rd param for both new vth.
; 
; Method: First modifies the spex_summ structure, then the current fit_comp... parameters.  In both cases, the 2vth 
;   component is removed. Two vth components are added to the end of the components with default settngs.
;   The 2vth values for starting param, param, minima, maxima, free_mask, and sigma that were in the old structure are set 
;   into the corresponding locations of the arrays for the two new vth components.
;   
; Arguments:
; o - ospex object that you want to change
; 
; Written: 26-Aug-2013, Kim Tolbert
;-


pro spex_convert_2vth_to_twovth, o

; First change spex_summ structure values 
s = o->get(/spex_summ)
sfunc = s.spex_summ_fit_function
scomp = str2arr(sfunc, '+')

if (where(scomp eq '2vth'))[0] ne -1 and (where(scomp eq 'vth'))[0] eq -1 then begin

  s_old = str_subset(s,['*params','*minima', '*maxima', '*free_mask', '*sigmas', '*func_spectrum', '*func_model'], /regex)  ; save old values
  iold = fit_function_query(sfunc, /param_elem, comp='2vth')
  ; iold points to em1,t1,em2,t2,abun. change to point to em1,t1,abun,em2,t2,abun
  iold = [iold[0:1], iold[4], iold[2:3], iold[4]]
  
  spex_change_summ_comp, summ=s, comp_remove='2vth', comp_add='vth'
  spex_change_summ_comp, summ=s, comp_add='vth'
  
  inew0 = fit_function_query(s.spex_summ_fit_function, /param_elem, comp='vth#0')
  inew1 = fit_function_query(s.spex_summ_fit_function, /param_elem, comp='vth#1')
  inew = [inew0,inew1]  ; inew are indices of both vth components
  s.spex_summ_starting_params[inew,*] = s_old.spex_summ_starting_params[iold,*]
  s.spex_summ_params[inew,*] = s_old.spex_summ_params[iold,*]
  s.spex_summ_minima[inew,*] = s_old.spex_summ_minima[iold,*]
  s.spex_summ_maxima[inew,*] = s_old.spex_summ_maxima[iold,*]
  s.spex_summ_free_mask[inew,*] = s_old.spex_summ_free_mask[iold,*]
  s.spex_summ_sigmas[inew,*] = s_old.spex_summ_sigmas[iold,*]
  
  o->set, _extra=s
  message, /cont, 'Removed 2vth, added two vths, and set modified spex_summ structure in object.'
  
endif
  
  ; Now change current fit function and fit_comp params
func = o->get(/fit_function)
; iold are the indices of the 2vth values in the old fit_comp arrays 
iold = fit_function_query(func, /param_elem, comp='2vth')
if iold[0] ne -1 then begin

  ; iold points to em1,t1,em2,t2,abun. change to point to em1,t1,abun,em2,t2,abun
  iold = [iold[0:1], iold[4], iold[2:3], iold[4]]
  
  ; save old 2vth values
  old_fc = o->get(/fit_comp_params,/fit_comp_minima, /fit_comp_maxima, /fit_comp_free_mask)
  
  ; remove 2vth and add two vths (will be at end of list of components)
  o->set,fit_function='-2vth'
  o->set,fit_function='+vth+vth'
  
  ; inew will be indices of the vth values in the new fit_comp arrays
  func_new = o->get(/fit_function)
  inew0 = fit_function_query(func_new, /param_elem, comp='vth#0')
  inew1 = fit_function_query(func_new, /param_elem, comp='vth#1')
  inew = [inew0, inew1]
  
  ; get new arrays of fit_comp params and insert old values from 2vth into parallel locations for the two vths
  new_fc = o->get(/fit_comp_params,/fit_comp_minima, /fit_comp_maxima, /fit_comp_free_mask)
  new_fc.fit_comp_params[inew] = old_fc.fit_comp_params[iold]
  new_fc.fit_comp_minima[inew] = old_fc.fit_comp_minima[iold]
  new_fc.fit_comp_maxima[inew] = old_fc.fit_comp_maxima[iold]
  new_fc.fit_comp_free_mask[inew] = old_fc.fit_comp_free_mask[iold]
  
  ; and set new fit_comp arrays back into object
  o->set, _extra=new_fc
  message, /cont, 'Removed 2vth, added two vths, and set modified function and fit_comp arrays in object.'
endif

end


