;+
; Name: spex_draw_bars
;
; Purpose: Draw bars across the top of plots in ospex to show filter states
;
; Method:  When /show_filter is set on call to plot_time, the utplot object
;   contains addplot_name='spex_draw_bars', and addplot_arg = a structure
;   containing the values for the keyword arguments needed here.
;   The bar for time periods with the same label are drawn at the same y value,
;     different labels are shifted downward in y.
;
; Input Keywords:
;   stime - array of start times
;   etime - array of end times
;   label - array of labels corresponding to those start/end times
;
; Written: Kim Tolbert 10-Apr-2005.  Extracted from spex_gen__filter_bars so
;   that it could be used with the addplot... stuff in utplot
; Modifications:
;
;-


pro spex_draw_bars, $
	stime=stime, etime=etime, label=label

psymsave=!p.psym
!p.psym=0

charsize = ch_scale(.8, /xy)

uniq_label = get_uniq(label)
nuniq = n_elements(uniq_label)

for j=0,nuniq-1 do begin
	w = where (label eq uniq_label[j])
	mark_intervals, stime[w], etime[w], label=uniq_label[j], n_bar=n_bar, $
		color=250, charsize=charsize
endfor

!p.psym = psymsave

end
