;+
; Name: spex_fermi_lat__define
;
; Purpose: Provide methods to deal with the fermi_lat data when downloading spectrum and rsp files for OSPEX
;   
; Written: Kim Tolbert, 6-Dec-2012  copied from spex_fermi_gbm__define
; 21-Oct-2010, Kim.  Delete download method. Add inherit spex_instr (and use its download method)
; 08-Aug-2011, Kim.  Add flare_time keyword to time2rsp method
; 02-Oct-2011, Kim.  Added download method.  Use spex_instr::download as usual, but then
;   for the unique dates that were copied by spex_instr::download, download the corresponding poshist files.
; 26-Jan-2012, Kim. Changed order method to return sorted filenames (previously indices), and group spectrum and response
;   files for each detector, also returns 'best' keyword with indices of (up to) 4 most sunward of files. Addec time keyword
;   to search, and modified select_files to use new version of order.
; 18-Dec-2013, Kim. Put online
;-

function spex_fermi_lat::init
return,1
end

;-----

pro spex_fermi_lat::cleanup
end

;-----

function spex_fermi_lat::search, time_range, pha=pha, rsp=rsp, count=count, pattern=pattern, _ref_extra=extra, lc=lc
checkvar, pattern, keyword_set(lc) ? 'LC_' : 'spectrum_'
nlat = 0 & lat_url=''
nrsp = 0 & rsp_url=''
checkvar, pha, 0
checkvar, rsp, 0
both = (pha+rsp eq 0)

if pha or both then spex_find_data, 'fermi_lat', time_range, pattern=pattern, url=lat_url, count=nlat, _extra=extra
if rsp or both then spex_find_data, 'fermi_lat_rsp', time_range,  url=rsp_url, count=nrsp, _extra=extra
;help,nlat,nrsp
count = nlat + nrsp

if count eq 0 then return, ''
url = [lat_url, rsp_url]
return, rem_blanks(url)
end

;-----
pro spex_fermi_lat::download, files, copyfiles=copyfiles, dir=dir, err=err

self -> spex_instr::download, files, copyfiles=copyfiles, dir=dir, err=err 

end

;-----

; Select the spectrum and rsp files
pro spex_fermi_lat::select_files, files, time_range, specfile, drmfile

specfile = ''
drmfile = ''

; specfile will be a scalar or array of all lat spectrum files needed for user's time range
q = where (stregex(file_basename(files), 'spectrum_', /bool) eq 1, count)
if count gt 0 then specfile = files[q]

; drm should be a single file, don't know which, so just select first
q = where (stregex(file_basename(files), 'rsp', /bool) eq 1, count)
if count gt 0 then drmfile = files[q[0]]

end

;-----

pro spex_fermi_lat__define
void = {spex_fermi_lat, inherits spex_instr}
end