;+
; Name: spex_get_filter
;
; Purpose: Return filter values grouped by index.  If any filter in the group
;   is -99 (unknown state) or the the filter changes within a group, return a -99
;   for that group.
;
; Category: OSPEX
;
; Calling sequence:  fil = spex_get_filter (filters, index)
;
; Input:
;   filters - array of filters (normally one for every raw time interval)
;   index - array of start/end indices to group filters by
;
; Example:
;   filters = [0,0,-99,1,1,1,0,0,0,3,3,3]
;   index = [0,1] returns 0
;   index = [0,2] returns -99
;   index = [[6,8],[9,11]] returns 0,3
;   index = [6,10] returns -99
;
; Written: 19-Jul-2004, Kim
; Modifications:
;
;-

function spex_get_filter, filters, index

if size(filters,/tname) eq 'POINTER' then return, -1
if filters[0] eq -1 then return, -1

nbin = n_elements(index[0,*])
val = intarr(nbin)
for i = 0,nbin-1 do begin
	filt = filters[index[0,i]:index[1,i]]
	q = where (filt eq -99, count)
	; if there are any -99's or if value changes, bad interval, set to -99.
	val[i] = (count gt 0 or min(filt) ne max(filt)) ? -99 : filt[0]
endfor

return, val

end