;+
; NAME: apar_check
;
; PURPOSE: reconcile array of parameters with initial values for parameters and number of
;	   intervals
;
; CATEGORY: spectral analysis
;
; CALLING SEQUENCE: apar_check, apar, nint, apar_arr [, force=force], apar_last=apar_last
;
; CALLED BY: SPEX
;
; INPUTS:
;	apar - default starting parameters, 1-d vector, npar elements
;	nint - number of spectral intervals
;       /force - if set then all intervals are loaded with apar
;
; OUTPUTS:
;       apar_arr - fltarr( npar, nint)
;	apar_last- fltarr( npar, nint)
; PROCEDURE: If apar_arr (and apar_last) is (are) not consistent in number with n_elements(apar) 
;	     and nint (number of intervals), then it is made consistent, if it is consistent 
;	     then it is unchanged unless /force is used.
;
; MODIFICATION HISTORY: 14-feb-94
;
;-

pro apar_check, apar, nint, apar_arr, apar_last=apar_last, force=force

npar = n_elements(apar)

checkvar, apar_arr, rebin( reform(apar, npar, 1),npar, nint)
checkvar, apar_last, rebin( reform(apar, npar, 1),npar, nint)

if n_elements(apar_arr(*,0)) ne npar or n_elements(apar_arr(0,*)) ne nint or keyword_set(force) then $
	apar_arr = rebin( reform(apar, npar, 1), npar, nint)

if n_elements(apar_last(*,0)) ne npar or n_elements(apar_last(0,*)) ne nint or keyword_set(force) then $
	apar_last = rebin( reform(apar, npar, 1), npar, nint)

end

	

