;+
; PROJECT: SPEX
; NAME:   drm_albedo
;
;
; PURPOSE:  To include photospheric albedo into DRM for original spex program.
;
;
; CATEGORY: SPEX, spectral analysis
;
;
; CALLING SEQUENCE:
;
;   drm_albedo,theta,anisotropy
;   Example: drm_albedo, 90., 1
;
;
; INPUTS:
;	 theta (degrees) - heliocentric angle of the flare in degrees (default is 45 degrees)
;    anisotropy      - a coefficient showing the ratio of the flux in observer direction
;                      to the flux downwards
;                      if anisotropy=1 (default) the source is isotropic
;
; OUTPUTS:
;	drm	    - detector response matrix per input photon/cm2 in cnts/cm2/keV with albedo
;             correction
;             changes drm in spex common
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	works only for integer binning of edges and E_in
;
; PROCEDURE:
;	none
;
; MODIFICATION HISTORY:
;	eduard@astro.gla.ac.uk, 5-July-2004
;   6-Aug-2004, Kim Tolbert.  Made this a wrapper for calling drm_correct_albedo, so that
;     ospex can also call drm_correct_albedo. (This ones uses the spex_commons (which is
;     specific to spex) to get the photon edges, and to store the new drm.)
;-

pro drm_albedo,angle,anisotropy

@spex_commons

; drm and e_in arrays are in spex_commons
newdrm = drm_correct_albedo (theta=angle, anisotropy=anisotropy, drm=drm, ph_edges=e_in, /verbose)
if newdrm[0] ne -1 then begin
	print,'SPEX> read_drm to load original DRM'
	drm = newdrm
endif

end