
;+
; NAME: low_e_spec_eff
;	
; PURPOSE: calculate the low energy cross section for 
;	BATSE spec detectors from materials and geometry
;	Only considers the front surface.  Validity limited
;	to energies less than 14.0 keV
; CALLING SEQUENCE:
;	result = low_e_spec_eff( e_in, theta)
; INPUTS:
;	e_in - energy in keV
;	theta - angle in degrees le 90 degrees
; OPTIONAL INPUTS:
;	be_add - more window cross-section in effective beryllium
;		 thickness
; OUTPUTS:
;	photopeak area in cm2
; OPTIONAL OUTPUTS:
;
; PROCEDURE:
;
; CALLS:
;	xsec, other_filters
; COMMON BLOCKS:
;
; RESTRICTIONS:
;
; MODIFICATION HISTORY:
;	ras, 2-mar-95
;	ras, 14-dec-95	
;-
;
function low_e_spec_eff, e_in, theta, be_add=be_add

thetar=theta /!radeg


bcrossx = xsec(e_in,4,'pe') +  xsec(e_in,4,'si')/2
barea   = !pi*3.81^2
acrossx = xsec(e_in,13,'pe') +  xsec(e_in,13,'si')/2 
scrossx = xsec(e_in,14,'pe') +  xsec(e_in,14,'si')/2 

annulus = !pi*(6.515^2-3.81^2) *cos( thetar) /exp( ((acrossx*.068 +scrossx*.15)/cos( thetar))<30. )
checkvar, be_add, 0.35 	;thickness to reconcile Tom Skelton's millipore paper attenuation

return, (barea*cos( thetar) /exp(bcrossx*(.127+be_add)/cos( thetar)) $
	+ annulus) * other_filters(e_in,/multi)^(4./cos( thetar))

end
