;+
; Project     : SDAC
;
; Name        : SPEX_DATA_OUT
;
; Purpose     : This function extracts variable from the SPEX common blocks into a structure.
;
; Category    : SPEX, I/O
;
;
; Syntax      : data_str = spex_data_out( /arg1, /arg2, ...)
;
;
; Examples    :
;IDL> out=spex_data_out(/obsi,/backi,/apar,/convi,/edges)
;IDL> help,out,/st
;** Structure <4485588>, 5 tags, length=1864, data length=1864, refs=1:
;   APAR            FLOAT     Array[6]
;   BACKI           FLOAT     Array[92]
;   CONVI           FLOAT     Array[92]
;   EDGES           FLOAT     Array[2, 92]
;   OBSI            FLOAT     Array[92]

;
; Inputs      :
;
; Opt. Inputs :
;
; Opt. Outputs: Returns a structure.  See example above.  There is one tag in the structure
;	for every valid argument.
;
; Keyword Inputs    :
; 	Arg1 - Variables from spex_commons to extract.  See spex_commons.pro and spex_current.pro
;		Some examples are FLUX, RATE, OBSI, BACKI, EDGES
;		Any and all of the variables may be selected. The full variable name must
;		be used.
; Calls	      :
;		SPEX_CURRENT, ADD_TAG
; Common      :
;
; Restrictions:
;
;
;
; History     : Version 1, RAS, 21-FEB-2003
;
; Contact     : Richard.Schwartz@gsfc.nasa.gov
;-
function spex_data_out, _extra=_extra
tags = tag_names( _extra )


ntags = n_elements(tags)
temp = spex_current(tags[0])
out = create_struct( tags[0], temp)
if ntags ge 2 then $
	for i=1,ntags-1 do begin
	temp = spex_current(tags[i])
	out = add_tag( out, temp, tags[i])
	endfor
return, out
end