;+
;
; NAME: 
;	SPEX_HANDLES_FIND
;
; PURPOSE:
;	This function returns the top handle id for the requested data structure.
;
; CATEGORY:
;	SPEX
;
; CALLING SEQUENCE:
;	Match_ids = SPEX_HANDLES_FIND( Search_struct )
;
; CALLS:
;	none
;
; INPUTS:
;       Search_str - A structure used to pattern match existing handle structures
;	used in SPEX.  
;
; OPTIONAL INPUTS:
;	none
;
; OUTPUTS:
;	Match_ids - Output of this function. 
;	The ids that match the Search_struct in DATA_TIPE, DET_ID, and TYPE (INPUT, DRM, or FIT)
;       Children - If 1 unique match is found to the search structure, then
;	the child ids are returned starting at the first child with the siblings in order.
;
; OPTIONAL OUTPUTS:
;
; KEYWORDS:
;	SELECT_ID - If this value is set, it is used to find the exact dataset from
;	otherwise identical datasets in data_tipe, det_id, and type.
;	TOP_HANDLES - Matching SPEX_HANDLES structures corresponding
;	to returned IDs
; COMMON BLOCKS:
;	none
;
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	This is not a stand-alone routine, but is internal to the SPEX handle routines.
;	Assumes that there are no more than 10,000 handles
; PROCEDURE:
;	This function looks for the top handles that have the name
;	spex_handles and then matches it to the Search_str and returns
;	its id.  If no Search_str which is a SPEX_HANDLES structure, then all the 
;	handle ids for all the SPEX_HANDLES structures are returned, and TOP_HANDLES
;	is an array of all the SPEX_HANDLES structures.
;
; MODIFICATION HISTORY:
;	ras, 5-Apr-1996
;-
function  Spex_handles_find, Search_str, Children, TOP_HANDLES=TOP_HANDLES, SELECT_ID=SELECT_ID

children = 0
test = indgen(10000)
true = handle_info( test )	;can't be more than 10,000 handles. right?
;
; Find the handles
;
wids = where( true gt 0, nids)
if nids eq 0 then return, 0
test = test(wids)	;these are handles
wtop_ids = where( handle_info(test,/parent) eq 0, ntop)
if ntop eq 0 then return, 0
top_ids  = test(wtop_ids)
top_handles = replicate( spex_handles_str(), ntop) ;up to this many top handle structures
count = 0
for i=0,ntop-1 do begin
	handle_value, top_ids(i), str
	if datatype(str) eq 'STC' then $
	if tag_names(/struct, str) eq 'SPEX_HANDLES' then begin
		top_handles(count) = str
		count = count + 1
	endif else top_ids(i)=0
endfor

if count eq 0 then return, 0	;Could not find any SPEX_HANDLES handle structures
;
; Remove non SPEX_HANDLES top handles from list
;
top_ids = top_ids( where( top_ids gt 0))
top_handles = top_handles(0:count-1)

;
; If there is no requested search_str or it is a not a SPEX_HANDLES structure name,
; then return all the top handle structures ids.
;
if datatype( search_str ) ne 'STC' then return, top_ids
if tag_names( search_str,/stru ) ne 'SPEX_HANDLES' then return, top_ids
	
wmatch= where( top_handles.det_id eq search_str.det_id and $
	strupcase( strtrim(top_handles.data_tipe(0),2)) eq $
	strupcase( strtrim(search_str.data_tipe(0),2)) and $
	strupcase( strtrim(top_handles.data_tipe(1),2)) eq $
	strupcase( strtrim(search_str.data_tipe(1),2)) and $
	strupcase( strtrim(top_handles.type,2) ) eq strupcase(strtrim(search_str.type,2)), $
	nmatch)

if nmatch eq 0 then return, 0
;So far we've found a structure that matches data_tipe, det_id, and type
;If there is more than 1 of these, select on select_id
tops = top_ids( wmatch )
top_handles = top_handles( wmatch)
if keyword_set(select_id) then begin
	wmatch = where( top_handles.select_id eq select_id, nmatch)
	if nmatch eq 0 then return,0
	top_handles = top_handles(wmatch)
	tops = tops(wmatch)
endif
nchild = handle_info( tops(0), /num )
if nmatch eq 1 and nchild gt 0 then begin
	children = intarr( nchild )
	children(0) = 	handle_info( tops(0), /first)
	for i=1,n_elements(children)-1 do $
		children(i)=handle_info(/sibling, children(i-1))
endif					


return, tops

end

