;+
;
; NAME: 
;	SPEX_HANDLES_STR
;
; PURPOSE:
;	This procedure creates the structure used in the SPEX_HANDLES* procedures.
;	It also loads the tags with the input values.
;
; CATEGORY:
;	SPEX, HANDLES
;
; CALLING SEQUENCE:
;	Result = SPEX_HANDLES_STR( Data_tipe, Det_id, Type, Select_id, README=README, $
;	EVENT_ID=EVENT_ID)
;
; CALLS:
;	none
;
; INPUTS:
;       Data_tipe: SPEX data_tipe option, e.g. ['BATSE','SHERS']
;	Det_id: Detector ID, 0 if not-applicable
;	Type: 'INPUT', 'DRM', or 'FIT'
;	Select_id: Numerical ID of similar handle data sets, 0 is first, such
;	as 3 for the fourth version of 'FIT'
;	
; OPTIONAL INPUTS:
;	none
;
; OUTPUTS:
;       none explicit, only through commons;
;
; OPTIONAL OUTPUTS:
;	none
;
; KEYWORDS:
;	README: A string with more information about the data set
;	EVENT_ID: A unique string identifier when used with DATA_TIPE and DET_ID, e.g.
;		'Flare=3030' or 'Files=continuous_ibdb_1674.fits' 
; COMMON BLOCKS:
;	none
;
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	none
;
; PROCEDURE:
;	none
;
; MODIFICATION HISTORY:
;	ras, 7-april-1996
;-
Function SPEX_HANDLES_STR,   Data_tipe, Det_id, Type, Select_id, README=README, $
	EVENT_ID=EVENT_ID
checkvar, data_tipe, strarr(2)
checkvar, det_id, 0L
checkvar, type, 'INPUT'
checkvar, select_id, 0L
checkvar, readme, ''
checkvar, event_id, ''

handles_str = { spex_handles, $
	data_tipe: data_tipe, $
	det_id: det_id(0)*1L, $
	type: type(0), $
	select_id:select_id(0)*1L, $
	readme:readme(0), $
	event_id:event_id(0) }

return, handles_str
end


