;+
;
; NAME: spex_merge_control
;
;
; PURPOSE: process the creation, editing, and processing
;	of the merging of database files within SPEX
;
;
; CATEGORY: SPEX
;
;
; CALLING SEQUENCE:  
;	spex_merge_control, com_param, merge_list, input_line, mscript
;
; CALLED BY: SPEX
;
;
; CALLS:
;	XSTRUCT, f_use_widget, spex_current
;
; INPUTS:
;       com_param - command modifier from SPEX input
;		    Values with meaning:
;		    '' - create merge_list, mscript and input_line to run
;		         based on the current values of the flare
;		    'CURRENT' - create mscript and input_line based on the
;			        current values of merge_list 
;		    'NORUN'   - create merge_list based on the current values
;			        of the flare
;		    'EDIT'    - edit merge_list
;		    			
;
; OPTIONAL INPUTS:
;	none
;
; OUTPUTS:
;       merge_list - structure with database specifications
;	input_line - control instructions for SPEX, string
;	mscript    - created from merge_list, a string array
;		     with consecutive instructions for SPEX
;
; OPTIONAL OUTPUTS:
;	none
;
; COMMON BLOCKS:
;	none
;
; SIDE EFFECTS:
;	none
;
; RESTRICTIONS:
;	As of 16-oct-1995, only BATSE CONT and BATSE DISCSP have automatic merging.
;	Data files really must cover exactly the same time intervals.
; PROCEDURE:
;	none
;
; MODIFICATION HISTORY:
;	ras, 16-oct-1995
;	ras, 21-oct-1996, changed to use merge_batse
;-


pro spex_merge_control, com_param, merge_list, mscript, input_line

input_line='DATA_TIPE,BATSE,DISCSP_CONT'
;more,com_param
mscript=fcheck(mscript,'')
return


datalist = merge_list.datalist(0)
for i=0,n_tags(datalist)-1 do $
	if datatype(datalist.(i)) eq 'STR' then datalist.(i)='' else $
	datalist.(i)= 0

      flare=spex_current('flare')

;CONSULT THE BATSE DETECTOR DATABASE
call_procedure,"det_cosines", flare=flare, /sort, lad_sort=lad_sort, spec_sort=spec_sort
spec_ids =  strtrim( spec_sort(0:1), 2)
lad_ids  =  strtrim( lad_sort(0:1), 2)

do_merge_list = 1
do_mscript    = 1
do_input_line = 1
do_edit = 0

com_param = strupcase( com_param)
case com_param(0) of
	'CURRENT': do_merge_list = 0
	'NORUN':   do_input_line = 0
	'EDIT': begin
	do_input_line = 0
	do_mscript = 1
	do_merge_list = 0
	do_edit = 1
	end
	else:
endcase

if do_merge_list then begin
  merge_list.number = 4
  merge_list.datalist = replicate(datalist,10)
  for i=0,1 do begin
	merge_list.datalist(i).data_tipe=['BATSE','CONT']
	merge_list.datalist(i).flare=flare
	merge_list.datalist(i).det_id=lad_sort(i)
	merge_list.datalist(i+2).data_tipe=['BATSE','DISCSP']
	merge_list.datalist(i+2).flare=flare
	merge_list.datalist(i+2).det_id=spec_sort(i)
  endfor
endif

if do_mscript then begin
  tnames = tag_names(merge_list.datalist)
  ntags  = n_elements(tnames)
  mscript = strarr((2+ntags)*merge_list.number+1+4)
  mscript(0) = ['idl,spex_source,/clear']
  im = 1
  for i=0,merge_list.number -1 do begin
	for j=0,ntags-1 do begin
	  newval = arr2str(string( merge_list.datalist(i).(j) ),delim=',')
	  if newval ne ',' and newval ne '' then begin
		 mscript(im)=  tnames(j)+','+newval
		 im = im+1
	  endif
	endfor
	if i eq 0 then mscript(im)= $
	  [ '/ !! graph','idl, spex_source & spex_delete,wchan=wchan & spex_hold'] $
	else $
	  mscript(im)= ['graph','idl, spex_source & spex_delete,wchan=wchan & spex_merge']
	im = im+2
   endfor
   mscript(im)=[ 'energy,6,7,10,30,30.,100.,100.,500.',$
    'graph', 'idl,edge_products, e_in, gm=em_in, width=w_in',$
   'idl, edge_products, edges, mean=emdge & wedge=delta_light']
   mscript=mscript( where(mscript ne '') )
	


;  for i=0,merge_list.number -1 do $
;    if i eq 0 then $
;    mscript(1+i*3:1+i*3+2) = $
;    ['idl, temp=spex_current( /by_tag, input=merge_list.datalist('+strtrim(i,2)+'))', $
;    '/ !! graph','idl, spex_source & spex_delete,wchan=wchan & spex_hold'] $
;    else $
;    mscript(1+i*3:1+i*3+2) = $
;    ['idl, temp=spex_current( /by_tag, input=merge_list.datalist('+strtrim(i,2)+'))', $
;    'graph','idl, spex_source & spex_delete,wchan=wchan & spex_merge']
;    mscript = [mscript,  'energy,6,7,10,30,30.,100.,100.,500.',$
;    'graph', 'idl,edge_products, e_in, gm=em_in, width=w_in',$
;   'idl, edge_products, edges, mean=emdge & wedge=delta_light']

   printx,['This is the series of commands to be executed consecutively:',mscript]
endif

if do_input_line then input_line = arr2str(mscript,delim = '!!')   

if do_edit then begin
  if f_use_widget(/test) then begin 
	modify_merge_list, merge_list
  endif else $
  print, 'You must exit SPEX and modify the structure MERGE_LIST within IDL'
  for i=0,n_tags(datalist)-1 do $
  if datatype(merge_list.datalist.(i)) eq 'STR' then $
  	merge_list.datalist.(i)=strcompress(/remove,merge_list.datalist.(i))
		  
endif




      ;mscript = ['data,batse,cont','det_id,'+ lad_ids(0),'graph', $
      ;'idl,spex_source,/clear & spex_source & spex_delete,[0] & spex_hold', $
      ;'det_id,'+ lad_ids(1),'graph', $
      ;'idl,spex_source & spex_delete,[0] & spex_merge', $
      ;'det_id,'+ spec_ids(0),'data,batse,discsp', 'graph', $
      ;'idl,spex_source  &spex_merge', $
      ;'det_id,'+ spec_ids(1),'graph', $
      ;'idl,spex_source & spex_merge','energy,6,7,10,30,30.,100.,100.,500.',$
      ;	'graph', 'idl,edge_products, e_in, gm=em_in, width=w_in',$
      ;	'idl, edge_products, edges, mean=emdge & wedge=delta_light']

end
